# Currently only contains the version identifier
# Examples of this style:
# - https://github.com/pypa/warehouse/blob/64ca42e42d5613c8339b3ec5e1cb7765c6b23083/warehouse/__about__.py
# - https://github.com/python-excel/xlrd/blob/master/xlrd/info.py

__version__ = '0.4b2'
